@@ -162,13 +162,11 @@ def waitpid(pid, opts):
 
 
 def fsencode(s):
-    return s
-    if type(s) == bytes:
+    if type(s) is bytes:
         return s
-    return bytes(s, "ascii")
+    return bytes(s, "utf-8")
 
 def fsdecode(s):
-    return s
-    if type(s) == str:
+    if type(s) is str:
         return s
-    return str(s, "ascii")
+    return str(s, "utf-8")
